isAvailable property
bool
get
isAvailable
Whether the native backend library can be loaded on this device.
Implementation
static bool get isAvailable => QhexrtBindings.checkAvailability();
Whether the native backend library can be loaded on this device.
static bool get isAvailable => QhexrtBindings.checkAvailability();