QhexrtBindings.fromDynamicLibrary constructor
QhexrtBindings.fromDynamicLibrary(
- DynamicLibrary _backend
Bind an explicitly loaded QHexRT library.
This keeps host-side FFI contract tests on the same wrapper path used by Android while production callers continue to use QhexrtBindings.
Implementation
QhexrtBindings.fromDynamicLibrary(this._backend) {
_bindFunctions();
}